.. image:: _static/yutipy_header.png
   :alt: Welcome to yutipy's documentation!
   :target: https://github.com/CheapNightbot/yutipy

**yutipy** is a Python package for searching and retrieving music information from various music platforms, including Deezer, iTunes, Spotify, and YouTube Music. This documentation will help you get started with yutipy and provide detailed information about its features and usage.

Get Started
===========

.. toctree::
   :maxdepth: 2

   installation
   usage_examples
   api_reference
